.. This README is meant for consumption by humans and PyPI. PyPI can render rst files so please do not use Sphinx features.
   If you want to learn more about writing documentation, please check out: http://docs.plone.org/about/documentation_styleguide.html
   This text does not appear on PyPI or github. It is a comment.

.. image:: https://github.com/collective/collective.flexmailhost/actions/workflows/plone-package.yml/badge.svg
    :target: https://github.com/collective/collective.flexmailhost/actions/workflows/plone-package.yml

.. image:: https://coveralls.io/repos/github/collective/collective.flexmailhost/badge.svg?branch=main
    :target: https://coveralls.io/github/collective/collective.flexmailhost?branch=main
    :alt: Coveralls

.. image:: https://codecov.io/gh/collective/collective.flexmailhost/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/collective/collective.flexmailhost

.. image:: https://img.shields.io/pypi/v/collective.flexmailhost.svg
    :target: https://pypi.python.org/pypi/collective.flexmailhost/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/status/collective.flexmailhost.svg
    :target: https://pypi.python.org/pypi/collective.flexmailhost
    :alt: Egg Status

.. image:: https://img.shields.io/pypi/pyversions/collective.flexmailhost.svg?style=plastic   :alt: Supported - Python Versions

.. image:: https://img.shields.io/pypi/l/collective.flexmailhost.svg
    :target: https://pypi.python.org/pypi/collective.flexmailhost/
    :alt: License


=======================
collective.flexmailhost
=======================

Sync mail settings to MailHost rather than patching it. Allows multiple MailHosts per Plone site.



Installation
------------

Install collective.flexmailhost by adding it to your buildout::

    [buildout]

    ...

    eggs =
        collective.flexmailhost


and then running ``bin/buildout``


Authors
-------

Maik Derstappen - MrTango - md@derico.de


Contributors
------------

Put your name here, you deserve it!

- ?


Contribute
----------

- Issue Tracker: https://github.com/collective/collective.flexmailhost/issues
- Source Code: https://github.com/collective/collective.flexmailhost


Support
-------

If you are having issues, please let us know.


License
-------

The project is licensed under the GPLv2.
